@@ -1,5 +1,5 @@
 #!/bin/bash
-# $Id: bootstrap.sh 3 2006-07-27 18:14:19Z lennart $
+# $Id: bootstrap.sh 31 2007-10-30 00:28:17Z lennart $
 
 # This file is part of paprefs.
 #
@@ -24,12 +24,12 @@ run_versioned() {
     local V
 
     V=$(echo "$2" | sed -e 's,\.,,g')
-    
+
     if [ -e "`which $1$V`" ] ; then
-    	P="$1$V" 
+    	P="$1$V"
     else
 	if [ -e "`which $1-$2`" ] ; then
-	    P="$1-$2" 
+	    P="$1-$2"
 	else
 	    P="$1"
 	fi
@@ -44,11 +44,18 @@ set -ex
 if [ "x$1" = "xam" ] ; then
     run_versioned automake "$VERSION" -a -c --foreign
     ./config.status
-else 
+else
     rm -rf autom4te.cache
     rm -f config.cache
 
-    run_versioned aclocal "$VERSION"
+    rm -f Makefile.am~ configure.ac~
+    # Evil, evil, evil, evil hack
+    sed 's/read dummy/\#/' `which gettextize` | sh -s -- --copy --force
+    test -f Makefile.am~ && mv Makefile.am~ Makefile.am
+    test -f configure.ac~ && mv configure.ac~ configure.ac
+
+    intltoolize --copy --force --automake
+    run_versioned aclocal "$VERSION" -I m4
     run_versioned autoconf 2.59 -Wall
     run_versioned autoheader 2.59
     run_versioned automake "$VERSION" -a -c --foreign
